@@ -7,6 +7,7 @@ from aiohttp import ClientResponse
 @dataclass
 class ResponseData:
 
+    service_name: str
     url: str
 
     started_at: float
@@ -35,6 +36,8 @@ class ResponseData:
 
         if '/' in self.host:
             self.host, self.route = self.host.split('/', 1)
+        else:
+            self.route = ''
 
         self.route = '/' + self.route
 
