@@ -10,14 +10,17 @@ import requests
 from flask import Flask
 from flask_sqlalchemy import SQLAlchemy
 
-from config import app_path
 from .models import CrawlerTask
 
 logger = getLogger()
 
 
 class BaseCrawlerAdapter():
-    tasks_path: Path = app_path.joinpath('crawling', 'tasks')
+
+    @property
+    def default_tasks_path(self) -> Path:
+        from app.config import app_path
+        return app_path.joinpath('crawling', 'tasks')
 
     @property
     def crawler_create_task_url(self):
@@ -35,10 +38,10 @@ class BaseCrawlerAdapter():
     def crawler_data_url(self):
         return f'{self.crawler_url}/data/get'
 
-    def __init__(self, app: Flask, db: SQLAlchemy, tasks_path: Path = app_path.joinpath('crawling', 'tasks')):
+    def __init__(self, app: Flask, db: SQLAlchemy, tasks_path: Path = None):
         self.app = app
         self.db = db
-        self.tasks_path = tasks_path
+        self.tasks_path = tasks_path if tasks_path else self.default_tasks_path
 
         self.crawler_url = app.config.get('CRAWLER_URL')
 
@@ -107,7 +110,8 @@ class BaseCrawlerAdapter():
             response = requests.post(self.crawler_task_status_url, json=data)
 
             if response.status_code != 200:
-                logger.warning(f'Check task status is not succeed. Status {response.status_code}. Payload: {response.text}')
+                logger.warning(
+                    f'Check task status is not succeed. Status {response.status_code}. Payload: {response.text}')
             logger.debug(response.text)
 
             status = response.json()['result']['status']
