@@ -1,9 +1,11 @@
+from avatar_utils.db.mixins.created_at import CreatedAtMixin
 from avatar_utils.db.mixins.crud import CRUDMixin
 from avatar_utils.db.mixins.json_cast import JsonCastMixin
 from avatar_utils.db.mixins.time_cast import TimeCastMixin
 
 __all__ = [
+    'CreatedAtMixin',
     'CRUDMixin',
-    'TimeCastMixin',
     'JsonCastMixin',
+    'TimeCastMixin',
 ]
