@@ -1,4 +1,4 @@
-from typing import Optional, Any
+from typing import Optional, Any, List, TypeVar
 
 from app import db
 
@@ -12,7 +12,7 @@ class CRUDMixin:
         return instance if instance is not None else cls.create(**kwargs)
 
     @classmethod
-    def create(cls, **kwargs) -> Optional[db.Model]:
+    def create(cls, **kwargs) -> 'CRUDMixin':
         kwargs = cls._preprocess_params(**kwargs)
         instance = cls(**kwargs)  # noqa
         db.session.add(instance)
@@ -20,12 +20,12 @@ class CRUDMixin:
         return instance
 
     @classmethod
-    def all(cls, **kwargs) -> Optional[db.Model]:
+    def all(cls, **kwargs) -> Optional[List['CRUDMixin']]:
         kwargs = cls._preprocess_params(**kwargs)
         return cls.query.filter_by(**kwargs).all()  # noqa
 
     @classmethod
-    def read(cls, **kwargs) -> Optional[db.Model]:
+    def read(cls, **kwargs) -> Optional['CRUDMixin']:
         kwargs = cls._preprocess_params(**kwargs)
         return cls.query.filter_by(**kwargs).first()  # noqa
 
