@@ -13,8 +13,8 @@ logger = getLogger(__name__)
 def before_request():
     log_prefix = f'[ LOGGING BEFORE | {request.remote_addr} {request.method} > {request.url_rule} ]'
     try:
-        log_id = Log.init(request)
-        g.log_id = log_id
+        log = Log.init(request)
+        g.log = log
     except DatabaseError as err:
         logger.warning(f'{log_prefix} < Rollback transaction due to: {err}')
         db.session.rollback()
@@ -26,10 +26,10 @@ def before_request():
 def after_request(response):
     log_prefix = f'[ LOGGING AFTER | {request.remote_addr} {request.method} > {request.url_rule} ]'
     try:
-        if g.log_id is not None:
-            Log.complete(g.log_id, response)
+        if g.log:
+            Log.complete(g.log, response)
         else:
-            print('log_id is None, cannot complete logging process')
+            logger.warning('log_id is None, cannot complete logging process')
     except DatabaseError as err:
         logger.warning(f'{log_prefix} < Rollback transaction due to: {err}')
         db.session.rollback()
