@@ -24,6 +24,9 @@ class Event(AbstractObject):
     image: Image = None
     tags: List[Any] = None
 
+    saved_in_calendar: bool = False
+    is_mandatory: bool = False
+
     repr_type: str = None
 
     id: int = None
