@@ -15,6 +15,8 @@ class Person(AbstractObject):
     firstname: str = None
     middlename: str = None
     image: Image = None
+    url: str = None
+    contacts: str = None
 
     repr_type: str = None
 
