@@ -10,10 +10,10 @@ from avatar_utils.objects.abstracts.abstract_object import AbstractObject
 class Tag(AbstractObject):
     service: str = None
     category: str = None
-    name: str = None
+    text: str = None
     created_at: str = None
-    updated_at: str = None
     approved_at: str = None
+    score: float = None
 
     repr_type: str = None
 
