@@ -1,7 +1,10 @@
 import logging
+from json import dumps as json_dumps
 
 import flask
 
+JSON_DECODE_ATTRS = dict(indent=2, ensure_ascii=False)
+
 logger = logging.getLogger(__name__)
 
 
@@ -37,3 +40,6 @@ class AbstractApp:
             logger.debug(json)
         else:
             logger.debug(response.data.decode())
+
+    def json_dumps(self, data):
+        return json_dumps(data, **JSON_DECODE_ATTRS)
