@@ -8,6 +8,9 @@ logger = logging.getLogger(__name__)
 
 
 class IntegrationTest(TestCase, RemoteApp):
+    logger.handlers.clear()
+    logging.basicConfig(level=logging.DEBUG,
+                        format='%(asctime)s %(levelname)s %(message)s')
 
     def setUp(self):
         super().setUp()
