@@ -2,9 +2,8 @@ from logging import getLogger
 
 from marshmallow import Schema, fields
 from marshmallow.validate import Equal
-from werkzeug.exceptions import BadRequest  # noqa: PyPackageRequirements
 
-__all__ = ['RootResponseSchema', 'SuccessResponseSchema', 'ErrorResponseSchema']
+from avatar_utils.objects import Tag
 
 logger = getLogger('sample-service')
 
@@ -27,3 +26,21 @@ class SuccessResponseSchema(ResponseSchema):
 
 class ErrorResponseSchema(ResponseSchema):
     success = fields.Bool(required=True, allow_none=False, validate=Equal(False), default=False)
+
+
+class ObjectsPostSchema(Schema):
+    objects = fields.List(fields.Raw(), required=False)
+
+
+class ServicePostRequestSchema(ObjectsPostSchema):
+    pass
+
+
+class ServiceResultPostResponseSchema(ObjectsPostSchema):
+    label = fields.Str(required=False)
+    objects = fields.List(fields.Raw(), required=True)
+    tags = fields.Nested(Tag.Schema, required=True, many=True)
+
+
+class ServicePostResponseSchema(SuccessResponseSchema):
+    result = fields.Nested(ServiceResultPostResponseSchema, required=True)
